require 'fltk'

class Board < Fltk::Widget
	def initialize(w,h)
		size(w,h)
		@row = 0
		@col = 0
	end
	
	def resize(x,y,w,h)
		@unit = w/8
		w = 8*@unit
		h = 8*@unit
		super(x,y,w,h)
	end

	def draw
		drawGrid
		drawPiece(@row,@col, Fltk::BLACK)
	end
	
	def handle(code)
		if(code == Fltk::ENTER)
			return true
		end
		if(code == Fltk::MOVE)
			@row = Fltk::event_y / @unit
			@col = Fltk::event_x / @unit
			redraw
		end
		return super(code)
	end
	
	def drawGrid
		Fltk::color(Fltk::BLUE)
		Fltk::rectf(x,y,w,h)
		Fltk::color(Fltk::WHITE)
		0.step(w, @unit) do | col | Fltk::line(x+col, y, x+col, y+h) end
		0.step(h, @unit) do | row | Fltk::line(x, y+row, x+w, y+row) end
	end
	
	def drawPiece(row,col, color)
		Fltk::color(color)
		thisX = col*@unit
		thisY = row*@unit
		Fltk::pie(thisX, thisY, @unit, @unit,0,360)
	end
	
end

class MyWindow < Fltk::DoubleWindow
	def initialize
		super(300, 300, 'Drawing')
		b = Board.new(w,h)
		resizable(self)
	end

end

MyWindow.new.show
Fltk::run
